CliPrompts class
Provides interactive CLI prompts for selecting iOS capabilities and options.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
promptGoogleMapsKey(
) → String - Prompts the user to enter their Google Maps API key and returns the value.
-
selectBackgroundModes(
) → List< String> - Prompts the user to select which background modes to enable and returns the corresponding plist string values.
-
selectCapabilities(
) → List< Capability> - Prompts the user to choose which capabilities to configure and returns the selected Capability values.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited