AppDelegateModifier constructor
AppDelegateModifier(
- String projectRoot
Creates an instance targeting the Flutter project at projectRoot.
Implementation
AppDelegateModifier(this.projectRoot);
Creates an instance targeting the Flutter project at projectRoot.
AppDelegateModifier(this.projectRoot);