EntitlementsCreator class

Creates ios/Runner/Runner.entitlements with the APS push environment key.

Constructors

EntitlementsCreator(String projectRoot)
Creates an instance targeting the Flutter project at projectRoot.

Properties

hashCode int
The hash code for this object.
no setterinherited
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() String
Creates Runner.entitlements with aps-environment set to development. Does nothing if the file already exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited