InfoPlistModifier class

Modifies ios/Runner/Info.plist to add capability-related entries.

Constructors

InfoPlistModifier(String projectRoot)
Creates an instance targeting the Flutter project at projectRoot.

Properties

hashCode int
The hash code for this object.
no setterinherited
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBackgroundModes(List<String> modes) List<String>
Adds or updates UIBackgroundModes in Info.plist with the given modes.
addNSLocation() String
Adds NSLocationWhenInUseUsageDescription to Info.plist.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited