InfoPlistModifier constructor
InfoPlistModifier(
- String projectRoot
Creates an instance targeting the Flutter project at projectRoot.
Implementation
InfoPlistModifier(this.projectRoot);
Creates an instance targeting the Flutter project at projectRoot.
InfoPlistModifier(this.projectRoot);