PbxprojModifier class

Modifies ios/Runner.xcodeproj/project.pbxproj to register files and update build settings for iOS capabilities.

Constructors

PbxprojModifier(String projectRoot)
Creates an instance targeting the Flutter project at projectRoot.

Properties

hashCode int
The hash code for this object.
no setterinherited
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addFirebase() String
Registers GoogleService-Info.plist and Runner.entitlements in the Xcode project and sets CODE_SIGN_ENTITLEMENTS on all build configurations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateDeploymentTarget() String
Raises IPHONEOS_DEPLOYMENT_TARGET to 15.0 in all build configurations where it is currently set below that value.

Operators

operator ==(Object other) bool
The equality operator.
inherited