PbxprojModifier constructor
PbxprojModifier(
- String projectRoot
Creates an instance targeting the Flutter project at projectRoot.
Implementation
PbxprojModifier(this.projectRoot);
Creates an instance targeting the Flutter project at projectRoot.
PbxprojModifier(this.projectRoot);