AppDelegateModifier class
Modifies ios/Runner/AppDelegate.swift to add Firebase and Google Maps setup.
Constructors
- AppDelegateModifier(String projectRoot)
-
Creates an instance targeting the Flutter project at
projectRoot.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addFirebase(
) → List< String> -
Adds Firebase imports,
MessagingDelegateconformance, setup code, and push-notification delegate methods toAppDelegate.swift. -
addGoogleMaps(
String apiKey) → List< String> -
Adds the
GoogleMapsimport andGMSServices.provideAPIKeycall withapiKeytoAppDelegate.swift. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited