ProjectValidator class
Validates that a directory is a valid Flutter project with an iOS target.
Constructors
- ProjectValidator(String projectRoot)
-
Creates an instance targeting the directory at
projectRoot.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → bool -
Returns
trueif all expected Flutter iOS project files and directories are present under projectRoot.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited